@@ -11,7 +11,7 @@ require AutoLoader;
     StartApp SetSetup SetExpose SetUpdate SetButton SetDelay ClearWindow
     BLUE CYAN GREEN INDIGO NUMBERS ORANGE PINK RED VIOLET YELLOW jprint jpprint
 );
-$VERSION = '1.2.1';
+$VERSION = '1.1';
 
 use Wharf::JDockApp::jtools;
 
@@ -109,12 +109,6 @@ The reason?  The XPM 'code' is compiled into the binary.
 
   Jettero Heller <jettero@voltar.org>
 
-=head1 THANKS
-
-Per Henrik Johansen <xxx@xxx.org>
-
-For helping hunt down some sagfaults.
-
 =head1 SEE ALSO
 
 perl(1), Wharf::JDockApp(3), Wharf::JDockApp::jtools(3).
